//
// StarDate.h
// StarDate class for astronomical calculations.
//    Copyright 1996,2002 by Akkana Peck.
// You may use or distribute this code under the terms of the GPL.
//

#ifndef STAR_DATE_H
#define STAR_DATE_H

#include <time.h>

typedef time_t Date;

// A date class which can calculate decimal years, and knows how
// to initialize itself from a string with decimal days, e.g.
// "1997 Apr 1.034170"
// Prints in a format like: "May 15 17:05:37 PDT 1997"
class StarDate
{
public:
    StarDate();
    StarDate(Date d);
    StarDate(char* s);
    StarDate(double julian);

    void set(Date d);
    void set(char* s);
    void set(double julian);

    void addDays(int days);
    
    double daysSince();
    double decimalYears();
    double getTimeAsDecimalDay();
    double getJulianDate();

    //
    // toString() prints the date and time, but not day of the week
    //
    char* toString();

protected:
    Date mDate;
};

#endif // STAR_DATE_H

